@@ -795,7 +795,7 @@ L.Storage.Map.include({
 
     reset: function () {
         this.resetOptions();
-        this.dirty_datalayers.forEach(function (datalayer) {
+        this.dirty_datalayers.slice().forEach(function (datalayer) {
             if (datalayer.isDeleted) {
                 datalayer.connectToMap();
             }
@@ -1029,7 +1029,7 @@ L.Storage.Map.include({
 
         builder = new L.S.FormBuilder(this, optionsFields, {
             callback: function (field) {
-                if (field !== 'options.popupTemplate') {
+                if (field !== 'options.popupTemplate' && field !== 'options.popupContentTemplate') {
                     this.eachDataLayer(function (datalayer) {
                         datalayer.redraw();
                     });
